@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright (c) 2007-2009 Thomas Pani & Jeremy Grossmann
+# Copyright (c) 2007-2010 Thomas Pani & Jeremy Grossmann
 #
 # Contributions by Pavel Skovajsa
 #
@@ -48,7 +48,7 @@ import pemubin
 
 
 __author__ = 'Thomas Pani and Jeremy Grossmann'
-__version__ = '0.3.2'
+__version__ = '0.7.3'
 
 QEMU_PATH = "qemu"
 QEMU_IMG_PATH = "qemu-img"
@@ -95,20 +95,28 @@ class xEMUInstance(object):
         self.console = ''
         self.image = ''
         self.nic = {}
+        self.nics = '6'
         self.udp = {}
+        self.capture = {}
         self.netcard = 'pcnet'
         self.kqemu = False
         self.kvm = False
         self.options = ''
         self.process = None
         self.workdir = WORKDIR
-        self.valid_attr_names = ['image', 'ram', 'console', 'netcard', 'kqemu', 'kvm', 'options']
+        self.valid_attr_names = ['image', 'ram', 'console', 'nics', 'netcard', 'kqemu', 'kvm', 'options']
 
     def create(self):
 
         self.workdir = os.path.join(os.getcwd(), self.name)
         if not os.path.exists(self.workdir):
             os.makedirs(self.workdir)
+            
+    def clean(self):
+        pass
+    
+    def unbase_disk(self):
+        pass
 
     def start(self):
         command = self._build_command()
@@ -157,7 +165,8 @@ class xEMUInstance(object):
             except pywintypes.error, e:
                 print >> sys.stderr, "Unable to stop Qemu instance", self.name
                 print >> sys.stderr, e[2]
-                return False
+                # ignore and continue
+                #return False
         else:
             import signal
             try:
@@ -165,25 +174,29 @@ class xEMUInstance(object):
             except OSError, e:
                 print >> sys.stderr, "Unable to stop Qemu instance", self.name
                 print >> sys.stderr, e
-                return False
+                # ignore and continue
+                #return False
         self.process = None
 
         return True
 
     def _net_options(self):
         options = []
-        for vlan in range(6):
+        for vlan in range(int(self.nics)):
             options.append('-net')
             if vlan in self.nic:
                 options.append('nic,vlan=%d,macaddr=%s,model=%s' % (vlan, self.nic[vlan], self.netcard))
             else:
-                # add a default NIC for Qemu (we always add 6 NICs)
+                # add a default NIC for Qemu
                 options.append('nic,vlan=%d,macaddr=00:00:ab:%02x:%02x:%02d,model=%s' % (vlan, random.randint(0x00, 0xff), random.randint(0x00, 0xff), vlan, self.netcard))
             if vlan in self.udp:
                 options.extend(['-net', 'udp,vlan=%s,sport=%s,dport=%s,daddr=%s' %
                         (vlan, self.udp[vlan].sport,
                          self.udp[vlan].dport,
                          self.udp[vlan].daddr)])
+            if vlan in self.capture:
+                options.extend(['-net', 'dump,vlan=%s,file=%s' % (vlan, self.capture[vlan])])
+
         return options
         
     def _ser_options(self):
@@ -237,6 +250,7 @@ class QEMUInstance(xEMUInstance):
     def _build_command(self):
         "Builds the command as a list of shell arguments."
         command = [self.bin]
+        command.extend(['-name', self.name])
         command.extend(['-m', str(self.ram)])
         command.extend(self._disk_options())
         command.extend(self._image_options())
@@ -271,7 +285,18 @@ class ASAInstance(QEMUInstance):
         self.kernel_cmdline = ''
         self.valid_attr_names += ['initrd', 'kernel', 'kernel_cmdline']
         
+    def clean(self):
+        
+        flash = os.path.join(self.workdir, self.flash_name)
+        if os.path.exists(flash):
+            try:
+                print "Deleting old flash file:", flash
+                os.remove(flash)
+            except (OSError, IOError), e:
+                print >> sys.stderr, "Execution failed:", e
+
     def _disk_options(self):
+        
         flash = os.path.join(self.workdir, self.flash_name)
         if not os.path.exists(flash):
             try:
@@ -279,6 +304,7 @@ class ASAInstance(QEMUInstance):
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
                 print >> sys.stderr, "Execution failed:", e
+
         return ('-hda', flash)
 
     def _image_options(self):
@@ -296,7 +322,37 @@ class JunOSInstance(QEMUInstance):
         self.swap_size = '1G'
         self.netcard = 'e1000'
     
+    def clean(self):
+        
+        flash = os.path.join(self.workdir, self.flash_name)
+        if os.path.exists(flash):
+            try:
+                print "Deleting old flash file:", flash
+                os.remove(flash)
+            except (OSError, IOError), e:
+                print >> sys.stderr, "Execution failed:", e
+    
+        swap = os.path.join(self.workdir, self.swap_name)
+        if os.path.exists(swap):
+            try:
+                print "Deleting old swap file:", swap
+                os.remove(swap)
+            except (OSError, IOError), e:
+                print >> sys.stderr, "Execution failed:", e
+    
+    def unbase_disk(self):
+        
+        flash = os.path.join(self.workdir, self.flash_name)
+        if os.path.exists(flash):
+            try:
+                print "Converting %s to have no base image" % flash
+                retcode = subprocess.call([self.img_bin, 'convert', '-O', 'qcow2', flash, flash])
+                print self.img_bin + ' returned with ' + str(retcode)
+            except OSError, e:
+                print >> sys.stderr, "Execution failed:", e
+    
     def _disk_options(self):
+        
         flash = os.path.join(self.workdir, self.flash_name)
         if not os.path.exists(flash):
             try:
@@ -304,6 +360,7 @@ class JunOSInstance(QEMUInstance):
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
                 print >> sys.stderr, "Execution failed:", e
+
         swap = os.path.join(self.workdir, self.swap_name)
         if not os.path.exists(swap):
             try:
@@ -311,6 +368,7 @@ class JunOSInstance(QEMUInstance):
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
                 print >> sys.stderr, "Execution failed:", e
+
         return (flash, '-hdb', swap)
     
 class IDSInstance(QEMUInstance):
@@ -325,21 +383,62 @@ class IDSInstance(QEMUInstance):
         self.img1_name = 'DISK1'
         self.img2_name = 'DISK2'
     
-    def _disk_options(self):
+    def clean(self):
+    
         img1 = os.path.join(self.workdir, self.img1_name)
+        if os.path.exists(img1):
+            try:     
+                print "Deleting old image file:", img1
+                os.remove(img1)
+            except (OSError, IOError), e:
+                print >> sys.stderr, "Execution failed:", e
+        
         img2 = os.path.join(self.workdir, self.img2_name)
-        if not os.path.exists(img1):
+        if os.path.exists(img2):
+            try:     
+                print "Deleting old image file:", img2
+                os.remove(img2)
+            except (OSError, IOError), e:
+                print >> sys.stderr, "Execution failed:", e
+    
+    def unbase_disk(self):
+        
+        img1 = os.path.join(self.workdir, self.img1_name)
+        if os.path.exists(img1):
+            try:
+                print "Converting %s to have no base image" % img1
+                retcode = subprocess.call([self.img_bin, 'convert', '-O', 'qcow2', img1, img1])
+                print self.img_bin + ' returned with ' + str(retcode)
+            except OSError, e:
+                print >> sys.stderr, "Execution failed:", e
+                
+        img2 = os.path.join(self.workdir, self.img2_name)
+        if os.path.exists(img2):
+            try:
+                print "Converting %s to have no base image" % img2
+                retcode = subprocess.call([self.img_bin, 'convert', '-O', 'qcow2', img2, img2])
+                print self.img_bin + ' returned with ' + str(retcode)
+            except OSError, e:
+                print >> sys.stderr, "Execution failed:", e
+    
+    def _disk_options(self):
+        
+        img1 = os.path.join(self.workdir, self.img1_name)
+        if not os.path.exists(img1): 
             try:
                 retcode = subprocess.call([self.img_bin, 'create', '-b', self.image1, '-f', 'qcow2', img1])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
                 print >> sys.stderr, "Execution failed:", e
-        if not os.path.exists(img2):
-            try:
+        
+        img2 = os.path.join(self.workdir, self.img2_name)
+        if not os.path.exists(img2): 
+            try:  
                 retcode = subprocess.call([self.img_bin, 'create', '-b', self.image2, '-f', 'qcow2', img2])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
                 print >> sys.stderr, "Execution failed:", e
+
         return ('-hda', img1, '-hdb', img2)
     
 class QemuDeviceInstance(QEMUInstance):
@@ -350,15 +449,46 @@ class QemuDeviceInstance(QEMUInstance):
         self.swap_name= 'SWAP'
         self.swap_size = '1G'
         self.netcard = 'e1000'
-    
-    def _disk_options(self):
+
+    def clean(self):
+
         flash = os.path.join(self.workdir, self.flash_name)
-        if not os.path.exists(flash):         
+        if os.path.exists(flash): 
+            try:
+                print "Deleting old flash file:", flash
+                os.remove(flash)
+            except (OSError, IOError), e:
+                print >> sys.stderr, "Execution failed:", e
+                
+        swap = os.path.join(self.workdir, self.swap_name)
+        if os.path.exists(swap):
+            try:
+                print "Deleting old swap file:", swap
+                os.remove(swap)
+            except (OSError, IOError), e:
+                print >> sys.stderr, "Execution failed:", e
+                
+    def unbase_disk(self):
+        
+        flash = os.path.join(self.workdir, self.flash_name)
+        if os.path.exists(flash):
+            try:
+                print "Converting %s to have no base image" % flash
+                retcode = subprocess.call([self.img_bin, 'convert', '-O', 'qcow2', flash, flash])
+                print self.img_bin + ' returned with ' + str(retcode)
+            except OSError, e:
+                print >> sys.stderr, "Execution failed:", e
+                
+    def _disk_options(self):
+        
+        flash = os.path.join(self.workdir, self.flash_name)
+        if not os.path.exists(flash):
             try:
                 retcode = subprocess.call([self.img_bin, 'create', '-b', self.image, '-f', 'qcow2', flash])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e 
+                print >> sys.stderr, "Execution failed:", e
+                
         swap = os.path.join(self.workdir, self.swap_name)
         if not os.path.exists(swap):
             try:
@@ -366,6 +496,7 @@ class QemuDeviceInstance(QEMUInstance):
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
                 print >> sys.stderr, "Execution failed:", e
+
         return (flash, '-hdb', swap)
 
 class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
@@ -391,8 +522,12 @@ class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
             'create_nic' : (3, 3),
             'create_udp' : (5, 5),
             'delete_udp' : (2, 2),
+            'create_capture' : (3, 3),
+            'delete_capture' : (2, 2),
             'start' : (1, 1),
             'stop' : (1, 1),
+            'clean': (1, 1),
+            'unbase': (1, 1),
             }
         }
 
@@ -667,6 +802,26 @@ class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
         if QEMU_INSTANCES[name].udp.has_key(int(vlan)):
             del QEMU_INSTANCES[name].udp[int(vlan)]
         self.send_reply(self.HSC_INFO_OK, 1, "OK")
+        
+    def do_qemu_create_capture(self, data):
+        name, vlan, path = data
+        if not name in QEMU_INSTANCES.keys():
+            self.send_reply(self.HSC_ERR_UNK_OBJ, 1,
+                            "unable to find Qemu '%s'" % name)
+            return
+
+        QEMU_INSTANCES[name].capture[int(vlan)] = path
+        self.send_reply(self.HSC_INFO_OK, 1, "OK")
+        
+    def do_qemu_delete_capture(self, data):
+        name, vlan = data
+        if not name in QEMU_INSTANCES.keys():
+            self.send_reply(self.HSC_ERR_UNK_OBJ, 1,
+                            "unable to find Qemu '%s'" % name)
+            return
+        if QEMU_INSTANCES[name].capture.has_key(int(vlan)):
+            del QEMU_INSTANCES[name].capture[int(vlan)]
+        self.send_reply(self.HSC_INFO_OK, 1, "OK")
 
     def do_qemu_start(self, data):
         name, = data
@@ -691,7 +846,24 @@ class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
                             "unable to stop instance '%s'" % name)
         else:
             self.send_reply(self.HSC_INFO_OK, 1, "Qemu '%s' stopped" % name)
-
+            
+    def do_qemu_clean(self, data):
+        name, = data
+        if not name in QEMU_INSTANCES.keys():
+            self.send_reply(self.HSC_ERR_UNK_OBJ, 1,
+                            "unable to find Qemu '%s'" % name)
+            return
+        QEMU_INSTANCES[name].clean()
+        self.send_reply(self.HSC_INFO_OK, 1, "OK")
+        
+    def do_qemu_unbase(self, data):
+        name, = data
+        if not name in QEMU_INSTANCES.keys():
+            self.send_reply(self.HSC_ERR_UNK_OBJ, 1,
+                            "unable to find Qemu '%s'" % name)
+            return
+        QEMU_INSTANCES[name].unbase_disk()
+        self.send_reply(self.HSC_INFO_OK, 1, "OK")
 
 class DaemonThreadingMixIn(SocketServer.ThreadingMixIn):
     daemon_threads = True
@@ -768,6 +940,11 @@ def main():
     server = QemuWrapperServer((host, port), QemuWrapperRequestHandler)
 
     print "Qemu TCP control server started (port %d)." % port
+    global IP
+    if IP:
+        print "Listenning on %s" % IP
+    else:
+        print "Listenning on all network interfaces"
     try:
         server.serve_forever()
     except KeyboardInterrupt:
@@ -776,7 +953,7 @@ def main():
 
 if __name__ == '__main__':
     print "Qemu Emulator Wrapper (version %s)" % __version__
-    print "Copyright (c) 2007-2009 Thomas Pani & Jeremy Grossmann"
+    print "Copyright (c) 2007-2010 Thomas Pani & Jeremy Grossmann"
     print
 
     if platform.system() == 'Windows':
