@@ -70,7 +70,19 @@ class AbstractNode(QtSvg.QGraphicsSvgItem):
         
         self.default_hostname_xpos = None
         self.default_hostname_ypos = None
+        
+        # Used by the undo process to prevent to ask again to choose an image
+        self.image_reference = None
 
+    def setRenderers(self, render_normal, render_select):
+        """ renderer_normal: QtSvg.QSvgRenderer
+            renderer_select: QtSvg.QSvgRenderer
+        """
+        
+        self.__render_normal = render_normal
+        self.__render_select = render_select
+        self.setSharedRenderer(self.__render_normal)      
+        
     def getState(self):
         """ Returns the current node state
         """
@@ -119,7 +131,7 @@ class AbstractNode(QtSvg.QGraphicsSvgItem):
     def changeHypervisor(self):
         """ Called to change an hypervisor
         """
-        
+
         if len(self.__edgeList) > 0:
             QtGui.QMessageBox.warning(globals.GApp.mainWindow, translate("AbstractNode", "Hypervisor"), 
                                       translate("AbstractNode", "The device must have no connection to other devices in order to change its hypervisor"))
@@ -146,6 +158,13 @@ class AbstractNode(QtSvg.QGraphicsSvgItem):
                 dynamips_hypervisor = self.dynagen.dynamips[hypervisor]
             else:
                 debug("Connection to an hypervisor: " + hypervisor)
+
+                # use project workdir
+                if globals.GApp.workspace.projectWorkdir:
+                    self.dynagen.defaults_config['workingdir'] = globals.GApp.workspace.projectWorkdir
+                elif globals.GApp.systconf['dynamips'].workdir:
+                    self.dynagen.defaults_config['workingdir'] = globals.GApp.systconf['dynamips'].workdir
+                
                 dynamips_hypervisor = self.dynagen.create_dynamips_hypervisor(host, int(port))
                 if not dynamips_hypervisor:
                     QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("AbstractNode", "Hypervisor"),
@@ -160,7 +179,7 @@ class AbstractNode(QtSvg.QGraphicsSvgItem):
                 self.dynagen.running_config[host + ':' + port][self.get_running_config_name()] = config
                 del self.dynagen.running_config[self.d][self.get_running_config_name()]
             self.set_hypervisor(dynamips_hypervisor)
-            self.get_dynagen_device()
+            self.reconfigNode(self.hostname)
             self.dynagen.update_running_config()
             QtGui.QMessageBox.information(globals.GApp.mainWindow, translate("AbstractNode", "Hypervisor"),
                                            unicode(translate("AbstractNode", "New hypervisor %s has been set on device %s")) % (hypervisor, self.hostname))
@@ -179,6 +198,24 @@ class AbstractNode(QtSvg.QGraphicsSvgItem):
             if command.getStatus() != None:
                 QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("AbstractNode", "Console port"), unicode(command.getStatus()))
                 globals.GApp.topology.undoStack.undo()
+                
+    def changeAUXPort(self):
+        """ Called to change the aux port
+        """
+
+        device = self.get_dynagen_device()
+        current_aux = 2500
+        if device.aux:
+            current_aux = device.aux
+        (port, ok) = QtGui.QInputDialog.getInteger(globals.GApp.mainWindow, translate("AbstractNode", "Change the aux port"),
+                                          unicode(translate("AbstractNode", "AUX port for %s:")) % self.hostname, current_aux, 1, 65535, 1)
+        if ok and device.aux != port:
+
+            command = undo.NewAUXPort(self, port)
+            globals.GApp.topology.undoStack.push(command)
+            if command.getStatus() != None:
+                QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("AbstractNode", "AUX port"), unicode(command.getStatus()))
+                globals.GApp.topology.undoStack.undo()
 
     def paint(self, painter, option, widget=None):
         """ Don't show the selection rectangle
@@ -228,6 +265,8 @@ class AbstractNode(QtSvg.QGraphicsSvgItem):
         """ Called when the mouse is hover the node
         """
 
+        # update tool tip
+        self.setCustomToolTip()
         if not self.isSelected() and self.__render_select:
             self.setSharedRenderer(self.__render_select)
 
@@ -252,6 +291,7 @@ class AbstractNode(QtSvg.QGraphicsSvgItem):
         """
 
         if edge in self.__edgeList:
+            edge.stopCapturing(showMessage=False)
             self.__edgeList.remove(edge)
 
     def getEdgeList(self):
@@ -358,14 +398,12 @@ class AbstractNode(QtSvg.QGraphicsSvgItem):
         self.textItem.setFlag(self.textItem.ItemIsMovable)
         if self.hostname_xpos == None and self.hostname_ypos == None:
             # use default positions
-            if self.default_hostname_xpos == None and self.default_hostname_ypos == None:
-                # compute default positions once
-                textrect = self.textItem.boundingRect()
-                textmiddle = textrect.topRight() / 2
-                noderect = self.boundingRect()
-                nodemiddle = noderect.topRight() / 2
-                self.default_hostname_xpos = nodemiddle.x() - textmiddle.x()
-                self.default_hostname_ypos = -25
+            textrect = self.textItem.boundingRect()
+            textmiddle = textrect.topRight() / 2
+            noderect = self.boundingRect()
+            nodemiddle = noderect.topRight() / 2
+            self.default_hostname_xpos = nodemiddle.x() - textmiddle.x()
+            self.default_hostname_ypos = -25
             self.textItem.setPos(self.default_hostname_xpos, self.default_hostname_ypos)
         else:
             # use user defined positions
