@@ -9,6 +9,7 @@ FILES=" Form_MainWindow
 	Form_NewProject
 	Form_Snapshots
 	Form_SymbolManager
+	Form_SymbolDialog
 	Form_Wizard
 	Form_StyleDialog
 	Form_StartupConfig
@@ -35,5 +36,5 @@ FILES=" Form_MainWindow
 for file in $FILES;
 do
     echo "Generating $file"
-    /opt/local/Library/Frameworks/Python.framework/Versions/2.6/bin/pyuic4 "$file.ui" > "$file.py"
+    /Library/Frameworks/Python.framework/Versions/2.7/bin/pyuic4 "$file.ui" > "$file.py"
 done
